=====
Notes
=====

Documentation
-------------
Read up on how to write great documentation:

* https://realpython.com/documenting-python-code/
* https://docs.python-guide.org/writing/documentation/
* numpy docstring style: https://sphinxcontrib-napoleon.readthedocs.io/en/latest/example_numpy.html#example-numpy
* well written documentation: https://docs.cherrypy.org/en/latest/intro.html
* documentation-driven development: https://niccokunzmann.github.io/blog/2016-06-10/Documentation-Driven-Development
* on auto generation of docs and ReadTheDocs: https://samnicholls.net/2016/06/15/how-to-sphinx-readthedocs/

Package structure
-----------------
* https://github.com/bast/somepackage
* https://manikos.github.io/a-tour-on-python-packaging
* https://cookiecutter-pypackage.readthedocs.io/en/latest/readme.html

Package tools
-------------
* https://medium.com/better-programming/understanding-best-practice-python-tooling-by-comparing-popular-project-templates-6eba49229106

Open source projects
--------------------
* https://opensource.guide/

